# Pairs plots

# load our R-package
library(CDRVineMLE)

# some necessary functions
#################################################
# theoTau					#
# Input:					#
# param		parameter of the copula		#
# copula	copula family			#
# Output:					#
# tau		theo. Kendall's tau		#
#################################################

theoTau<-function(param,copula)
{
	if(copula=="N" | copula=="t")
	{
		tau=2/pi*asin(param)
	}
	else if(copula=="C")
	{
		tau=param/(param+2)
	}
	else if(copula=="G")
	{
		tau=1-1/param
	}
	else if(copula=="F")
	{
		f=function(x) {x/(exp(x)-1)}
		if(param>0)
		{
		tau=1-4/param+4/param^2*integrate(f,lower=0, upper=param)$value
		}
		else
		{
		tau=1-4/param-4/param^2*integrate(f,lower=param, upper=0)$value
		}
	}
	else if(copula=="J")
	{
		euler=0.57721
		tau=1+((-2+2*euler+2*log(2)+digamma(1/param)+digamma(1/2*(2+param)/param)+param)/(-2+param))
	}
	else if(copula=="BB1")
	{
		theta=param[1]
		delta=param[2]
		tau=1-2/(delta*(theta+2))
	}
	else if(copula=="BB7")
	{
		theta=param[1]
		delta=param[2]
		tau=1-2/(delta*(2-theta))+4/(theta^2*delta)*gamma(delta+2)*gamma((2-2*theta)/(theta)+1)/gamma(delta+3+(2-2*theta)/(theta))

	}

return(tau)
}


# Scatter plot of BB1 and BB7
u=runif(1000)
y=runif(1000)

thetaBB1=0.3
thetaBB7=2.1
deltaBB1=2.1
deltaBB7=0.3
bla=rep(0,1000)

out<-.C("Hinv",as.integer(7),as.integer(1000),as.double(y),as.double(u),as.double(thetaBB1), as.double(deltaBB1),as.double(bla),PACKAGE='CDVineMLE')
u1=out[[7]]
out<-.C("Hinv",as.integer(8),as.integer(1000),as.double(y),as.double(u),as.double(thetaBB7), as.double(deltaBB7),as.double(bla),PACKAGE='CDVineMLE')
u2=out[[7]]

X11(width=6, height=3.6)
par(mfrow=c(1,2))
plot(u,u1,xlab="u",ylab="v")
plot(u,u2,xlab="u",ylab="v")

# => tau, lambda_U, lambda_L
tau_BB1=theoTau(c(thetaBB1,deltaBB1),"BB1")
tau_BB7=theoTau(c(thetaBB7,deltaBB7),"BB7")

lambda_L_BB1=2^(-1/(thetaBB1*deltaBB1))
lambda_U_BB1=2-2^(1/deltaBB1)
lambda_L_BB7=2^(-1/deltaBB1)
lambda_U_BB7=2-2^(1/thetaBB7)

# contourplots
X11(width=6, height=7)
par(mfrow=c(2,2))
plot(u,u1,xlab="u",ylab="v")
plot(u,u2,xlab="u",ylab="v")
copContour(u,y,bw=1,size=100,levels=c(0.01,0.05,0.1,0.15,0.2), copula=7, param=c(thetaBB1,deltaBB1))
copContour(u,y,bw=1,size=100,levels=c(0.01,0.05,0.1,0.15,0.2), copula=8, param=c(thetaBB7,deltaBB7))
